==> microprofile-health-tck-3.0-sources.jar: org/eclipse/microprofile/health/tck/CDIProducedProceduresTest.java <==
/*
 * Copyright (c) 2019 Contributors to the Eclipse Foundation
 *
 * See the NOTICES file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 */

package org.eclipse.microprofile.health.tck;

import static org.eclipse.microprofile.health.tck.DeploymentUtils.createWarFileWithClasses;

import javax.json.JsonArray;
import javax.json.JsonObject;

import org.eclipse.microprofile.health.tck.deployment.CDIProducedProcedureCheck;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.shrinkwrap.api.Archive;
import org.testng.Assert;
import org.testng.annotations.Test;

/**
 * @author Prashanth Gunapalasingam
 */
public class CDIProducedProceduresTest extends TCKBase {
    @Deployment
    public static Archive getDeployment() {
        return createWarFileWithClasses(CDIProducedProceduresTest.class.getSimpleName(),
            CDIProducedProcedureCheck.class);
    }

    /**
     * Verifies the liveness and readiness health integration with CDI when the
     * Health Check procedures are defined with CDI Producers.
     */
    @Test
    @RunAsClient
    public void testSuccessfulLivenessResponsePayload() {
        Response response = getUrlLiveContents();

        // status code
        Assert.assertEquals(response.getStatus(), 200);

        JsonObject json = readJson(response);

        // response size
        JsonArray checks = json.getJsonArray("checks");
        Assert.assertEquals(checks.size(), 1, "Expected a single check response");

        // single procedure response
        assertSuccessfulCheck(checks.getJsonObject(0), "cdi-produced-successful-check");

        assertOverallSuccess(json);
    }

    /**
     * Tests that Readiness is down, for Readiness health check procedure
     * defined with CDI Producers.
     */
    @Test
    @RunAsClient
    public void testFailureReadinessResponsePayload() {
        Response response = getUrlReadyContents();

        // status code
        Assert.assertEquals(response.getStatus(), 503);

        JsonObject json = readJson(response);

        // response size
        JsonArray checks = json.getJsonArray("checks");
        Assert.assertEquals(checks.size(), 1, "Expected a single check response");

        // single procedure response
        assertFailureCheck(checks.getJsonObject(0), "cdi-produced-failed-check");

        assertOverallFailure(json);
    }
}

==> microprofile-health-tck-4.0.1-sources.jar: org/eclipse/microprofile/health/tck/CDIProducedProceduresTest.java <==
/*
 * Copyright (c) 2019, 2021 Contributors to the Eclipse Foundation
 *
 * See the NOTICES file(s) distributed with this work for additional
 * information regarding copyright ownership.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * You may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 */

package org.eclipse.microprofile.health.tck;

import static org.eclipse.microprofile.health.tck.DeploymentUtils.createWarFileWithClasses;

import org.eclipse.microprofile.health.tck.deployment.CDIProducedProcedureCheck;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.container.test.api.RunAsClient;
import org.jboss.shrinkwrap.api.Archive;
import org.testng.Assert;
import org.testng.annotations.Test;

import jakarta.json.JsonArray;
import jakarta.json.JsonObject;

/**
 * Verifies the liveness, readiness, and startup health integration with CDI when the Health Check procedures are
 * defined with CDI method Producers.
 *
 * @author Prashanth Gunapalasingam
 */
public class CDIProducedProceduresTest extends TCKBase {
    @Deployment
    public static Archive getDeployment() {
        return createWarFileWithClasses(CDIProducedProceduresTest.class.getSimpleName(),
                CDIProducedProcedureCheck.class);
    }

    /**
     * Verifies the successful Liveness Health Check integration with CDI method producers.
     */
    @Test
    @RunAsClient
    public void testSuccessfulLivenessResponsePayload() {
        Response response = getUrlLiveContents();

        // status code
        Assert.assertEquals(response.getStatus(), 200);

        JsonObject json = readJson(response);

        // response size
        JsonArray checks = json.getJsonArray("checks");
        Assert.assertEquals(checks.size(), 1, "Expected a single check response");

        // single procedure response
        assertSuccessfulCheck(checks.getJsonObject(0), "cdi-produced-successful-check");

        assertOverallSuccess(json);
    }

    /**
     * Verifies the failed Readiness Health Check integration with CDI method producers.
     */
    @Test
    @RunAsClient
    public void testFailureReadinessResponsePayload() {
        Response response = getUrlReadyContents();

        // status code
        Assert.assertEquals(response.getStatus(), 503);

        JsonObject json = readJson(response);

        // response size
        JsonArray checks = json.getJsonArray("checks");
        Assert.assertEquals(checks.size(), 1, "Expected a single check response");

        // single procedure response
        assertFailureCheck(checks.getJsonObject(0), "cdi-produced-failed-check");

        assertOverallFailure(json);
    }

    /**
     * Verifies the successful Startup Health Check integration with CDI method producers.
     */
    @Test
    @RunAsClient
    public void testSuccessStartupResponsePayload() {
        Response response = getUrlStartedContents();

        // status code
        Assert.assertEquals(response.getStatus(), 200);

        JsonObject json = readJson(response);

        // response size
        JsonArray checks = json.getJsonArray("checks");
        Assert.assertEquals(checks.size(), 1, "Expected a single check response");

        // single procedure response
        assertSuccessfulCheck(checks.getJsonObject(0), "cdi-produced-successful-check");

        assertOverallSuccess(json);
    }
}
